summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/ksnewstuff.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/ksnewstuff.h')
-rw-r--r--kstars/kstars/ksnewstuff.h8
1 files changed, 3 insertions, 5 deletions
diff --git a/kstars/kstars/ksnewstuff.h b/kstars/kstars/ksnewstuff.h
index fc653e55..a6e4cd49 100644
--- a/kstars/kstars/ksnewstuff.h
+++ b/kstars/kstars/ksnewstuff.h
@@ -32,8 +32,6 @@
#include <kdeversion.h>
-#if KDE_IS_VERSION( 3, 2, 90 )
-
#include <klocale.h>
#include <kdebug.h>
#include <tqobject.h>
@@ -46,12 +44,13 @@ class KStars;
class KSNewStuff : public TQObject, public KNewStuff
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
*Constructor
*@p parent pointer to the parent widget
*/
- KSNewStuff( TQWidget *parent = 0 );
+ KSNewStuff( TQWidget *tqparent = 0 );
/**
*Install new application data
@@ -90,5 +89,4 @@ class KSNewStuff : public TQObject, public KNewStuff
bool NGCUpdated;
};
-#endif // KDE >= 3.2.90
#endif // KSNEWSTUFF_H
@@ -46,12 +44,13 @@ class KStars;
/**
*Constructor
- *@p parent pointer to the parent widget
+ *@p tqparent pointer to the tqparent widget
*/